@@ -1,10 +1,12 @@
 /*
   SPDX-FileCopyrightText: 2015-2025 Laurent Montel <montel@kde.org>
 
-  SPDX-License-Identifier: GPL-2.0-only
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "filtersylpheedtest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "filterimportertest.h"
 #include "filterimportertestutil.h"
 #include <MailImporter/FilterSylpheed>
@@ -42,7 +44,7 @@ void FilterSylpheedTest::canNotImportDataUnknowPath()
     auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
-    filter.importMails(QStringLiteral("/foo/kde/bla/toto/"));
+    filter.importMails(u"/foo/kde/bla/toto/"_s);
     QVERIFY(importerTest->filterImporterDataList().isEmpty());
     delete importerTest;
 }
